@@ -3,7 +3,8 @@ import unittest
 import numpy as np
 
 import openmdao.api as om
-from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials
+from openmdao.utils.om_warnings import OpenMDAOWarning
+from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials, assert_warning, assert_no_warning
 from openmdao.utils.testing_utils import force_check_partials
 
 
@@ -498,5 +499,34 @@ class TestFeature(unittest.TestCase):
         assert_near_equal(p.get_val('totalforcecomp.total_force', units='kN'), expected_i)
 
 
+class TestDuplicateWarning(unittest.TestCase):
+
+    def test_if_warning(self):
+        """
+        Tests if a warning is issued when duplicate inputs are used
+        """
+        comp = om.AddSubtractComp()
+        input_names = ["f1", "f2", "f2", "f1", "f3"]
+        output_name = "f"
+        msg = f"Duplicate inputs are connected to '{output_name}'. This will " \
+              "double count the same value, which may cause unexpected behavior."
+        
+        with assert_warning(OpenMDAOWarning, msg, True):
+            comp.add_equation(output_name, input_names=input_names)
+
+    def test_no_warning(self):
+        """
+        Tests if no warning is issued when there are no duplicate inputs
+        """
+        comp = om.AddSubtractComp()
+        input_names = ["f1", "f2", "f3", "f4", "f5"]
+        output_name = "f"
+        msg = f"Duplicate inputs are connected to '{output_name}'. This will " \
+              "double count the same value, which may cause unexpected behavior."
+        
+        with assert_no_warning(OpenMDAOWarning, msg):
+            comp.add_equation(output_name, input_names=input_names)
+    
+
 if __name__ == '__main__':
     unittest.main()
